# PoissonCP2-V4.R : Regressions for Business and Private Parties series
#
# Estimates Poisson regression changepoint models for terrorist target
# data regressions.
#
# Patrick T. Brandt
# 20090326 : Initial version.
# 20090410 : Split to run half of the analysis in two files for longer
#            chains.  See PoissonCP*.R files
# 20090511 : Reduced set of covariates.

# Load the data -- based on the output of the setup.R file that
# aggregates the data.

# Read in the data
load("MonthlySeries.RData")

# Load the relevant libraries and files
library(zoo)
library(MCMCpack)
library(mvtnorm)
source("utility.R")
source("MCMCpoissonStatespace.R")
source("MCMCpoissonRegChangepoint.R")

N1 <- 2000
N2 <- 8000

# Loop over the datasets and the number of breaks
out.reg2 <- list()
k <- 1

# Start with just univariate analyses of the number of changepoints
max.m <- 4
set.seed(23)

for(i in 3:4)
{
    for(j in 1:max.m)
    {
        tmp <- MCMCpoissonRegChangepoint(event ~
                                         aborted +
                                         stopped +
                                         completed +
                                         people +
                                         property,
                                         data=as.data.frame(x.m[[i]]),
                                         m=j,
                                         b0 = rep(0, 6),
                                         B0 = diag(6),
                                         burnin=N1, mcmc=N2,
                                         verbose=5000,
                                         a=0.25*480/(j+1), b=0.25,
                                         marginal.likelihood="Chib95")

        out.reg2[[k]] <- tmp
        k <- k+1
        save.image("PoissonCP2-V4.RData")
    }
}


# Now generate the Bayes factor matrices

Business.BF <- BayesFactor(out.reg2[[1]], out.reg2[[2]],
                            out.reg2[[3]], out.reg2[[4]])


PrivateParties.BF <- BayesFactor(out.reg2[[5]], out.reg2[[6]],
                                 out.reg2[[7]], out.reg2[[8]])

save.image("PoissonCP2-V4.RData")

q(save="no")
